import * as React from 'react';
import { useField, Label, TextInput } from 'payload/components/forms';

export const GeoPicker: React.FC<{ path: string }> = ({ path }) => {
  const { value, setValue } = useField<string>({ path });
  const [latitude, setLatitude] = React.useState("");
  const [longitude, setLongitude] = React.useState("");

  const handleCityEnter = async (e) => {
    console.log("Handle key")
    if (e.key === 'Enter') {
      console.log("Enter: " + e.target.value)
      try {
        const response = await fetch(
          `https://nominatim.openstreetmap.org/search?format=json&q=${e.target.value}`
        );
        const data = await response.json();
        if (data && data.length > 0) {
          const { lat, lon } = data[0];
          setLatitude(lat);
          setLongitude(lon);
          setValue([lon, lat]);
          console.log(data)
        }
      } catch (error) {
        console.error('Error fetching geolocation:', error);
      }
    }
  };

  const handleLatitudeChange = (e) => {
    setLatitude(e.target.value);
  };

  const handleLongitudeChange = (e) => {
    setLongitude(e.target.value);
  };

  return (
    <div>
      <div className='field-type text'>
        <label className='field-label'>
          City
        </label>
        <input
          type="text"
          className='field-name'
          onKeyDown={handleCityEnter}
          placeholder="Enter city to get coordinates"
        />
      </div>
      <div className="field-type point">
        <ul className='point__wrap'>
          <li>
            <label className='field-label'>Location - Longitude</label>
            <input id="field-longitude-location" type="number" name="location.longitude" value={longitude} onChange={handleLongitudeChange}></input>
          </li>
          <li>
            <label className='field-label'>Location - Latitude</label>
            <input id="field-latitude-latitude" type="number" name="location.latitude" value={latitude} onChange={handleLatitudeChange}></input>
          </li>
        </ul>
      </div>
    </div>
  );
};
